@@ -6,10 +6,10 @@ use fil_actors_runtime::runtime::{ActorCode, Runtime};
 use fil_actors_runtime::{
     actor_error, wasm_trampoline, ActorDowncast, ActorError, SYSTEM_ACTOR_ADDR,
 };
-use fvm_ipld_blockstore::Blockstore;
-use fvm_ipld_encoding::RawBytes;
 use fvm_shared::actor::builtin::Type;
 use fvm_shared::address::Address;
+use fvm_shared::blockstore::Blockstore;
+use fvm_shared::encoding::RawBytes;
 use fvm_shared::error::ExitCode;
 use fvm_shared::{ActorID, MethodNum, METHOD_CONSTRUCTOR};
 use num_derive::FromPrimitive;
@@ -45,10 +45,7 @@ impl Actor {
         let sys_ref: &Address = &SYSTEM_ACTOR_ADDR;
         rt.validate_immediate_caller_is(std::iter::once(sys_ref))?;
         let state = State::new(rt.store(), params.network_name).map_err(|e| {
-            e.downcast_default(
-                ExitCode::USR_ILLEGAL_STATE,
-                "failed to construct init actor state",
-            )
+            e.downcast_default(ExitCode::ErrIllegalState, "failed to construct init actor state")
         })?;
 
         rt.create(&state)?;
@@ -66,20 +63,14 @@ impl Actor {
 
         log::trace!("called exec; params.code_cid: {:?}", &params.code_cid);
 
-        let caller_code = rt
-            .get_actor_code_cid(&rt.message().caller())
-            .ok_or_else(|| {
-                actor_error!(
-                    USR_ILLEGAL_STATE,
-                    "no code for caller as {}",
-                    rt.message().caller()
-                )
-            })?;
+        let caller_code = rt.get_actor_code_cid(&rt.message().caller()).ok_or_else(|| {
+            actor_error!(ErrIllegalState, "no code for caller as {}", rt.message().caller())
+        })?;
 
         log::trace!("caller code CID: {:?}", &caller_code);
 
         if !can_exec(rt, &caller_code, &params.code_cid) {
-            return Err(actor_error!(USR_FORBIDDEN;
+            return Err(actor_error!(ErrForbidden;
                     "called type {} cannot exec actor type {}",
                     &caller_code, &params.code_cid
             ));
@@ -96,10 +87,9 @@ impl Actor {
         // Allocate an ID for this actor.
         // Store mapping of pubkey or actor address to actor ID
         let id_address: ActorID = rt.transaction(|s: &mut State, rt| {
-            s.map_address_to_new_id(rt.store(), &robust_address)
-                .map_err(|e| {
-                    e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to allocate ID address")
-                })
+            s.map_address_to_new_id(rt.store(), &robust_address).map_err(|e| {
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to allocate ID address")
+            })
         })?;
 
         // Create an empty actor
@@ -114,10 +104,7 @@ impl Actor {
         )
         .map_err(|err| err.wrap("constructor failed"))?;
 
-        Ok(ExecReturn {
-            id_address: Address::new_id(id_address),
-            robust_address,
-        })
+        Ok(ExecReturn { id_address: Address::new_id(id_address), robust_address })
     }
 }
 
@@ -140,7 +127,7 @@ impl ActorCode for Actor {
                 let res = Self::exec(rt, rt.deserialize_params(params)?)?;
                 Ok(RawBytes::serialize(res)?)
             }
-            None => Err(actor_error!(SYS_INVALID_METHOD; "Invalid method")),
+            None => Err(actor_error!(SysErrInvalidMethod; "Invalid method")),
         }
     }
 }
